==> nos-promise-1.0.0.tgz: package/submodule/nos-nodejs-sdk/lib/httpRequest/putObjectRequest.js <==
/**
 * Created by hzlichaolin on 2016/7/14.
 * this module can upload a file or string or json
 */

var httpRequest = require('./httpRequest')
var inherits = require('./inherits')
var authrization = require('../services/authorization')
var crypto = require('crypto')
var encoder = require('../services/urlEncoder')

function putObjectRequest() {
    httpRequest.call(this)

    this.options = {host: null, port: -1, path: null, method: 'PUT', headers:{}
    };

    this.bucketName = null
    this.x_nos_storage_class = null
    this.objectName = null
    this.body = null
}

inherits(putObjectRequest,httpRequest)

putObjectRequest.prototype.setBucketName = function (bucketName) {
    this.bucketName = bucketName
}

putObjectRequest.prototype.setObjectName = function (objectName) {
    this.objectName = encoder(objectName)
}

putObjectRequest.prototype.setStorageClass = function (storageClass) {
    this.x_nos_storage_class = storageClass
}

putObjectRequest.prototype.setCustomMetaData = function (key, value) {
    this.options.headers[key] = value
}

putObjectRequest.prototype.setBody = function (body) {
    this.body = body
}

putObjectRequest.prototype.sendRequest = function (func) {
    // this.objectName = escape(this.objectName)
    this.options.path = '/' + this.bucketName + '/' + this.objectName
    if (this.x_nos_storage_class != null){
        this.options.headers['x-nos-storage-class'] = this.x_nos_storage_class
    }
    this.options.headers['Date'] = (new Date()).toUTCString();
    this.options.body = this.body
    this.options.headers['Content-Length'] = this.body.length
    this.options.headers['Content-MD5'] = crypto.createHash('md5').update(this.options.body).digest('hex')
    var authStr = authrization(this.accessId,this.secretKey,this.options.method,this.options.headers,this.options.path)
    this.options.headers['Authorization'] = authStr
    httpRequest.prototype.sendRequest(this.options,func);
}

module.exports = putObjectRequest

==> nos-promise-1.0.2.tgz: package/submodule/nos-nodejs-sdk/lib/httpRequest/putObjectRequest.js <==
/**
 * Created by hzlichaolin on 2016/7/14.
 * this module can upload a file or string or json
 */

var httpRequest = require('./httpRequest')
var inherits = require('./inherits')
var authrization = require('../services/authorization')
var crypto = require('crypto')
var encoder = require('../services/urlEncoder')

function putObjectRequest() {
    httpRequest.call(this)

    this.options = {host: null, port: -1, path: null, method: 'PUT', family: 4, headers:{}
    };

    this.bucketName = null
    this.x_nos_storage_class = null
    this.objectName = null
    this.body = null
}

inherits(putObjectRequest,httpRequest)

putObjectRequest.prototype.setBucketName = function (bucketName) {
    this.bucketName = bucketName
}

putObjectRequest.prototype.setObjectName = function (objectName) {
    this.objectName = encoder(objectName)
}

putObjectRequest.prototype.setStorageClass = function (storageClass) {
    this.x_nos_storage_class = storageClass
}

putObjectRequest.prototype.setCustomMetaData = function (key, value) {
    this.options.headers[key] = value
}

putObjectRequest.prototype.setBody = function (body) {
    this.body = body
}

putObjectRequest.prototype.sendRequest = function (func) {
    // this.objectName = escape(this.objectName)
    this.options.path = '/' + this.bucketName + '/' + this.objectName
    if (this.x_nos_storage_class != null){
        this.options.headers['x-nos-storage-class'] = this.x_nos_storage_class
    }
    this.options.headers['Date'] = (new Date()).toUTCString();
    this.options.body = this.body
    this.options.headers['Content-Length'] = this.body.length
    this.options.headers['Content-MD5'] = crypto.createHash('md5').update(this.options.body).digest('hex')
    var authStr = authrization(this.accessId,this.secretKey,this.options.method,this.options.headers,this.options.path)
    this.options.headers['Authorization'] = authStr
    httpRequest.prototype.sendRequest(this.options,func);
}

module.exports = putObjectRequest
